summaryrefslogtreecommitdiff
path: root/src/exchange/taler-exchange-httpd_keys.h
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2020-12-09 23:39:11 +0100
committerChristian Grothoff <christian@grothoff.org>2020-12-09 23:39:11 +0100
commit5a24334e83dabcb00e0e0f4292a678b6820ea370 (patch)
treed404d8358f0d812cffcc668b2a9185cab1fafad2 /src/exchange/taler-exchange-httpd_keys.h
parent788f84f695589fad2afac9f3f600869d114fb79e (diff)
downloadexchange-5a24334e83dabcb00e0e0f4292a678b6820ea370.tar.gz
exchange-5a24334e83dabcb00e0e0f4292a678b6820ea370.tar.bz2
exchange-5a24334e83dabcb00e0e0f4292a678b6820ea370.zip
complete new implementation of GET /keys
Diffstat (limited to 'src/exchange/taler-exchange-httpd_keys.h')
-rw-r--r--src/exchange/taler-exchange-httpd_keys.h34
1 files changed, 25 insertions, 9 deletions
diff --git a/src/exchange/taler-exchange-httpd_keys.h b/src/exchange/taler-exchange-httpd_keys.h
index 614851482..dc78e0e54 100644
--- a/src/exchange/taler-exchange-httpd_keys.h
+++ b/src/exchange/taler-exchange-httpd_keys.h
@@ -191,9 +191,9 @@ TEH_keys_exchange_sign_ (const struct
/* check 'ps' begins with the purpose */ \
GNUNET_static_assert (((void*) (ps)) == \
((void*) &(ps)->purpose)); \
- TEH_exchange_sign_ (&(ps)->purpose, \
- pub, \
- sig); \
+ TEH_keys_exchange_sign_ (&(ps)->purpose, \
+ pub, \
+ sig); \
})
@@ -243,20 +243,36 @@ TEH_keys_management_get_handler (const struct TEH_RequestHandler *rh,
/**
- * Load fees and expiration times (!) for the denomination type configured
- * in section @a section_name. Before calling this function, the
- * `start` and `validity_duration` times must already be initialized in @a meta.
+ * Load fees and expiration times (!) for the denomination type configured for
+ * the denomination matching @a h_denom_pub.
*
* @param section_name section in the configuration to use
* @param[in,out] meta denomination type data to complete
* @return #GNUNET_OK on success
*/
int
-TEH_keys_load_fees (const char *section_name,
+TEH_keys_load_fees (const struct GNUNET_HashCode *h_denom_pub,
struct TALER_EXCHANGEDB_DenominationKeyMetaData *meta);
/**
+ * Load expiration times for the given onling signing key.
+ *
+ * @param exchange_pub the online signing key
+ * @param[out] start_sign starting signing time
+ * @param[out] end_sign send signing time
+ * @param[out] end_legal legal expiration time
+ * @return #GNUNET_OK on success
+ */
+int
+TEH_keys_get_timing (const struct TALER_ExchangePublicKeyP *exchange_pub,
+ struct GNUNET_TIME_Absolute *start_sign,
+ struct GNUNET_TIME_Absolute *end_sign,
+ struct GNUNET_TIME_Absolute *end_legal);
+
+
+/**
* Initialize keys submodule.
*
* @return #GNUNET_OK on success
@@ -243,20 +243,36 @@ TEH_keys_management_get_handler (const struct TEH_RequestHandler *rh,
*
- * @param section_name section in the configuration to use
- * @param[in,out] meta denomination type data to complete
+ * @param h_denom_pub hash of the denomination public key
+ * to use to derive the section name of the configuration to use
+ * @param[out] meta denomination type data to complete
* @return #GNUNET_OK on success
*/